@@ -53,8 +53,8 @@ class FEDSA_Classifier(_ImageClassifier):
         # normalize input data because SAM asserts only data between -1 and 1
         train_spectra_norm, tileimdata_norm = normalize_endmembers_image(endmembers, image)
 
-        angles = np.zeros((image.shape[0], image.shape[1], self.n_samples), np.float)
-        ed = np.zeros((image.shape[0], image.shape[1], self.n_samples), np.float)
+        angles = np.zeros((image.shape[0], image.shape[1], self.n_samples), float)
+        ed = np.zeros((image.shape[0], image.shape[1], self.n_samples), float)
         tileimspectra = im2spectra(image)
         # if np.std(tileimdata) == 0:  # skip tiles that only contain the same value
 
@@ -62,8 +62,8 @@ class FEDSA_Classifier(_ImageClassifier):
         for n_sample in range(self.n_samples):
             train_spectrum = train_spectra_norm[n_sample, :].reshape(1, 1, self.n_features)
             angles[:, :, n_sample] = calc_sam(tileimdata_norm, train_spectrum, axis=2)
-            ed[:, :, n_sample] = np.sqrt(np.sum((tileimspectra.astype(np.float) -
-                                                 train_spectrum.flatten().astype(np.float)) ** 2, axis=1))\
+            ed[:, :, n_sample] = np.sqrt(np.sum((tileimspectra.astype(float) -
+                                                 train_spectrum.flatten().astype(float)) ** 2, axis=1))\
                 .reshape(image.shape[:2])
 
         angles_norm = angles / angles.max()
