@@ -54,7 +54,7 @@ class SID_Classifier(_ImageClassifier):
         # normalize input data because SID asserts only data between -1 and 1
         train_spectra_norm, tileimdata_norm = normalize_endmembers_image(endmembers, imdata[:])
 
-        sid = np.zeros((imdata.shape[0], imdata.shape[1], self.n_samples), np.float)
+        sid = np.zeros((imdata.shape[0], imdata.shape[1], self.n_samples), float)
         # if np.std(tileimdata) == 0:  # skip tiles that only contain the same value
 
         # loop over all training spectra and compute spectral information divergence for each pixel
