@@ -34,8 +34,8 @@ def normalize_endmembers_image(endmembers, image):
     # type: (np.ndarray, np.ndarray) -> Tuple[np.ndarray, np.ndarray]
     from sklearn.preprocessing import MaxAbsScaler  # avoids static TLS errors here
 
-    em = endmembers.astype(np.float)
-    im = image.astype(np.float)
+    em = endmembers.astype(float)
+    im = image.astype(float)
 
     # provide training values as 2D ROW (n samples x 1 feature),
     # because normalization should be applied globally, not band-by-band
